## Kinase regulation profiles as molecular fingerprints of cellular signaling states

The diversity of the compiled perturbations as well as the extent of the kinases for which regulation is inferred constitutes a resource to study fundamental aspects of cell signaling. To demonstrate that the biological variation dominates over the technical variation, we tested if related kinases display co-regulation across conditions and, similarly, related conditions show similar patterns of kinase regulation. We observed that significant correlations between the KSEA activities were more frequent between kinases one or two steps away in the pathway than between those farther away (Fig EV4A). This observation remains true when excluding kinase-pairs sharing substrate sites (Fig EV4B). Similarly, we confirmed that pairs of related conditions measured in different studies tend to have similar profiles of KSEA activities (Fig EV4C). Furthermore, the correlation of kinase regulatory profiles is a very strong predictor of related conditions assayed in different studies (Fig EV4D, AUC=0.93), but not of pairs of conditions from studies conducted in the same lab (AUC=0.499), with the same cell line (AUC=0.546) or with the same labelling method (AUC=0.475). These results strongly suggest that the variation of kinase activities across conditions is primarily driven by biological effects rather than technical variation.

In order to explore the space of different signaling responses, we performed a principal component analysis (PCA) using the kinase regulation profiles derived from 58 well characterized kinases (Fig 3A, Materials and Methods, Appendix Fig S4). The first two components separate related EGF conditions based on their expected signaling similarities and opposite to the EGFR pathway inhibitors (Fig 3A, symbols). The separation of perturbations in the reduced space is again independent of the publication of origin, reflecting instead the similarities in the signaling response. The systematic exploration of conditions in the reduced space also allows us to investigate commonalities in the decision-making process. Kinase loadings driving the sample separation in the PCA space reflect systematic differences on the regulation of different kinases (Appendix Fig S4C). In this way, we can identify different types of kinase logic relationships that apply to nearly all conditions (Fig 3B). Some kinase pairs are co-regulated - such as BRAF and PRKG1 (Fig 3B, AND) - or anti-correlated - such as CDK2 and CHEK (Fig 3B, OR). Alternatively, we also identify pairs of kinases that display exclusive regulation, whereby one is never regulated at the same time as the other. For example, AKT1 is regulated when CDK1 is not and vice versa (Fig 3B, NOT).

The results above show how extreme similarities or dissimilarities between profiles of activity changes facilitate the interpretation and generate hypothesis about the signaling in specific conditions. For example, perturbations under DNA damaging conditions display similar KSEA activity profiles that can be summarized as a signature of marker kinases (Fig EV5). Among the most similar conditions to two DNA damage conditions (ionizing radiation and etoposide), are compounds that are known to cause DNA damage and a sample under G1-S transition obtained using a thymidine block that likely resulted in DNA damage. Conversely, cells treated with the inhibitor VE-821 targeting the DNA damage response kinase ATR show changes in activities anti-correlated with DNA damaging conditions (Fig EV5C). Therefore, kinase regulatory profiles can be used to identify perturbations that may mimic or modulate the kinase regulation occurring in a condition of interest. We further explored this notion in the study of two related Shigella and Salmonella infection states (Fig 3E). Among the anti-correlated conditions are 4 compounds that could potentially interfere with the infection process or the host response: SB202190 (p38 MAP kinase inhibitor), mesalazine (anti-inflamatory), trichostatin A (HDAC inhibitor) and verapamil (an efflux pump inhibitor). To validate the effect of these compounds, we have measured their impact on the invasion and proliferation of *Salmonella enterica Typhimurium* (STm) in human cells (Fig 3D, Materials and Methods). Mesalazine showed no effect on either invasion or proliferation (data not shown). Trichostatin A and higher doses of SB202190 tend to promote invasion. SB202190 showed a consistent decrease in long-term STm proliferation while trichostatin A showed a trend for increase in STm proliferation that was clearer for lower doses of the drug. Verapamil had a significant effect on proliferation that was not consistent across different concentrations. These results show how modulators of signaling states of interest can be identified by comparing kinase regulatory profiles found in the atlas.